@@ -1,6 +1,6 @@
 package HTTP::Throwable;
 our $AUTHORITY = 'cpan:STEVAN';
-$HTTP::Throwable::VERSION = '0.024';
+$HTTP::Throwable::VERSION = '0.025';
 use Types::Standard qw(Int Str ArrayRef);
 
 use Moo::Role;
@@ -101,7 +101,7 @@ HTTP::Throwable - a set of strongly-typed, PSGI-friendly HTTP 1.1 exception libr
 
 =head1 VERSION
 
-version 0.024
+version 0.025
 
 =head1 SYNOPSIS
 
@@ -205,7 +205,7 @@ as adding the L<StackTrace::Auto> role to your exceptions.
 
 This is the status code integer as specified in the HTTP spec.
 
-=head2 resason
+=head2 reason
 
 This is the reason phrase as specified in the HTTP spec.
 
@@ -416,7 +416,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Brian Cassidy Fitz Elliott Karen Etheridge
+=for stopwords Brian Cassidy Chris Prather Fitz Elliott Karen Etheridge
 
 =over 4
 
@@ -426,6 +426,10 @@ Brian Cassidy <bricas@cpan.org>
 
 =item *
 
+Chris Prather <chris@prather.org>
+
+=item *
+
 Fitz Elliott <felliott@fiskur.org>
 
 =item *
@@ -547,7 +551,7 @@ __END__
 #pod
 #pod This is the status code integer as specified in the HTTP spec.
 #pod
-#pod =attr resason
+#pod =attr reason
 #pod
 #pod This is the reason phrase as specified in the HTTP spec.
 #pod
