@@ -1,6 +1,6 @@
 package HTTP::Throwable::Factory;
 our $AUTHORITY = 'cpan:STEVAN';
-$HTTP::Throwable::Factory::VERSION = '0.023';
+$HTTP::Throwable::Factory::VERSION = '0.025';
 use strict;
 use warnings;
 
@@ -47,6 +47,12 @@ sub extra_roles {
 sub roles_for_ident {
     my ($self, $ident) = @_;
 
+    Carp::confess("roles_for_ident called with undefined ident")
+      unless defined $ident;
+
+    Carp::confess("roles_for_ident called with empty ident string")
+      unless length $ident;
+
     return "HTTP::Throwable::Role::Status::$ident";
 }
 
@@ -66,7 +72,11 @@ sub class_for {
 
     my @roles;
     if (defined $ident) {
-        @roles = $self->roles_for_ident($ident);
+        if ($ident =~ /\A[0-9]{3}\z/) {
+          @roles = $self->roles_for_status_code($ident);
+        } else {
+          @roles = $self->roles_for_ident($ident);
+        }
     } else {
         @roles = $self->roles_for_no_ident;
     }
@@ -85,6 +95,48 @@ sub class_for {
     return $class;
 }
 
+my %lookup = (
+    300 => 'MultipleChoices',
+    301 => 'MovedPermanently',
+    302 => 'Found',
+    303 => 'SeeOther',
+    304 => 'NotModified',
+    305 => 'UseProxy',
+    307 => 'TemporaryRedirect',
+
+    400 => 'BadRequest',
+    401 => 'Unauthorized',
+    403 => 'Forbidden',
+    404 => 'NotFound',
+    405 => 'MethodNotAllowed',
+    406 => 'NotAcceptable',
+    407 => 'ProxyAuthenticationRequired',
+    408 => 'RequestTimeout',
+    409 => 'Conflict',
+    410 => 'Gone',
+    411 => 'LengthRequired',
+    412 => 'PreconditionFailed',
+    413 => 'RequestEntityTooLarge',
+    414 => 'RequestURITooLong',
+    415 => 'UnsupportedMediaType',
+    416 => 'RequestedRangeNotSatisfiable',
+    417 => 'ExpectationFailed',
+
+    500 => 'InternalServerError',
+    501 => 'NotImplemented',
+    502 => 'BadGateway',
+    503 => 'Status::ServiceUnavailable',
+    504 => 'GatewayTimeout',
+    505 => 'HTTPVersionNotSupported',
+);
+
+sub roles_for_status_code {
+    my ($self, $code) = @_;
+
+    my $ident = $lookup{$code};
+    return $self->roles_for_ident($ident);
+}
+
 1;
 
 =pod
@@ -97,7 +149,7 @@ HTTP::Throwable::Factory - a factory that throws HTTP::Throwables for you
 
 =head1 VERSION
 
-version 0.023
+version 0.025
 
 =head1 OVERVIEW
 
@@ -168,6 +220,8 @@ This is the method you're most likely to override in a subclass.
 
 =head2 roles_for_ident
 
+=head2 roles_for_status_code
+
 =head2 roles_for_no_ident
 
 This methods convert the exception type identifier to a role to apply.  For
@@ -176,6 +230,7 @@ example, if you call:
   Factory->throw(NotFound => { ... })
 
 ...then C<roles_for_ident> is called with "NotFound" as its argument.
+C<roles_for_status_code> is used if the string is three ASCII digits.
 
 If C<throw> is called I<without> a type identifier, C<roles_for_no_ident> is
 called.
@@ -292,6 +347,8 @@ __END__
 #pod
 #pod =head2 roles_for_ident
 #pod
+#pod =head2 roles_for_status_code
+#pod
 #pod =head2 roles_for_no_ident
 #pod
 #pod This methods convert the exception type identifier to a role to apply.  For
@@ -300,6 +357,7 @@ __END__
 #pod   Factory->throw(NotFound => { ... })
 #pod
 #pod ...then C<roles_for_ident> is called with "NotFound" as its argument.
+#pod C<roles_for_status_code> is used if the string is three ASCII digits.
 #pod
 #pod If C<throw> is called I<without> a type identifier, C<roles_for_no_ident> is
 #pod called.
