@@ -1,10 +1,10 @@
 package HTTP::Throwable::Variant;
 our $AUTHORITY = 'cpan:STEVAN';
-$HTTP::Throwable::Variant::VERSION = '0.023';
+$HTTP::Throwable::Variant::VERSION = '0.025';
 use strict;
 use warnings;
 
-use Package::Variant
+use Package::Variant 1.002000
   importing => ['Moo', 'MooX::StrictConstructor'],
   subs      => [ qw(extends with) ];
 
@@ -27,7 +27,7 @@ HTTP::Throwable::Variant - a package that constructs Moo-based HTTP::Throwables
 
 =head1 VERSION
 
-version 0.023
+version 0.025
 
 =head1 OVERVIEW
 
